#!perl

use Test::More tests => 7;
use_ok("Net::Social::Mapper::Persona");
use_ok("Net::Social::Mapper::SiteMap");
use_ok("Net::Social::Mapper");
use_ok("Net::Social::Mapper::Persona::Email");
use_ok("Net::Social::Mapper::Persona::Flickr");
use_ok("Net::Social::Mapper::Persona::Generic");
use_ok("Net::Social::Mapper::Persona::Website");

